==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/ru/lang.php <==
<?php
/**
 * russian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Andrew Pleshakov <beotiger@mail.ru>
 */
$lang['menu']                  = 'Управление плагинами';
$lang['download']              = 'Скачать и установить новый плагин';
$lang['manage']                = 'Установленные плагины';
$lang['btn_info']              = 'данные';
$lang['btn_update']            = 'обновить';
$lang['btn_delete']            = 'удалить';
$lang['btn_settings']          = 'настройки';
$lang['btn_download']          = 'Скачать';
$lang['btn_enable']            = 'Сохранить';
$lang['url']                   = 'Адрес';
$lang['installed']             = 'Установлен:';
$lang['lastupdate']            = 'Последнее обновление:';
$lang['source']                = 'Источник:';
$lang['unknown']               = 'неизвестно';
$lang['updating']              = 'Обновление ...';
$lang['updated']               = 'Плагин %s успешно обновлен';
$lang['updates']               = 'Следующие плагины были успешно обновлены';
$lang['update_none']           = 'Обновления не найдены.';
$lang['deleting']              = 'Удаление ...';
$lang['deleted']               = 'Плагин %s удален.';
$lang['downloading']           = 'Скачивание ...';
$lang['downloaded']            = 'Плагин %s успешно установлен';
$lang['downloads']             = 'Следующие плагины были успешно установлены:';
$lang['download_none']         = 'Плагины не найдены, или возникла неизвестная проблема в процессе скачивания и установки.';
$lang['plugin']                = 'Плагин:';
$lang['components']            = 'Компоненты';
$lang['noinfo']                = 'Этот плагин не сообщил никаких данных, он может быть нерабочим.';
$lang['name']                  = 'Название:';
$lang['date']                  = 'Дата:';
$lang['type']                  = 'Тип:';
$lang['desc']                  = 'Описание:';
$lang['author']                = 'Автор:';
$lang['www']                   = 'Страничка:';
$lang['error']                 = 'Произошла неизвестная ошибка.';
$lang['error_download']        = 'Не могу скачать файл плагина: %s';
$lang['error_badurl']          = 'Возможно, неправильный адрес - не могу определить имя файла из адреса';
$lang['error_dircreate']       = 'Не могу создать временную директорию для скачивания';
$lang['error_decompress']      = 'Менеджеру плагинов не удалось распаковать скачанный файл. Это может быть результатом ошибки при скачивании, в этом случае Вы можете попробовать снова; или же плагин упакован неизвестным архиватором, тогда Вам необходимо скачать и установить плагин вручную.';
$lang['error_copy']            = 'Произошла ошибка копирования при попытке установки файлов для плагина <em>%s</em>: переполнение диска или неправильные права доступа. Это могло привести к частичной установке плагина и неустойчивости вашей Вики.';
$lang['error_delete']          = 'Произошла ошибка при попытке удалить плагин <em>%s</em>.  Наиболее вероятно, что нет необходимых прав доступа к файлам или директориям';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/ru/lang.php <==
<?php
/**
 * russian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Andrew Pleshakov <beotiger@mail.ru>
 * @author Змей Этерийский evil_snake@eternion.ru
 * @author Hikaru Nakajima <jisatsu@mail.ru>
 * @author Alexei Tereschenko <alexeitlex@yahoo.com>
 */
$lang['menu']                  = 'Управление плагинами';
$lang['download']              = 'Скачать и установить новый плагин';
$lang['manage']                = 'Установленные плагины';
$lang['btn_info']              = 'данные';
$lang['btn_update']            = 'обновить';
$lang['btn_delete']            = 'удалить';
$lang['btn_settings']          = 'настройки';
$lang['btn_download']          = 'Скачать';
$lang['btn_enable']            = 'Сохранить';
$lang['url']                   = 'Адрес';
$lang['installed']             = 'Установлен:';
$lang['lastupdate']            = 'Последнее обновление:';
$lang['source']                = 'Источник:';
$lang['unknown']               = 'неизвестно';
$lang['updating']              = 'Обновление ...';
$lang['updated']               = 'Плагин %s успешно обновлен';
$lang['updates']               = 'Следующие плагины были успешно обновлены';
$lang['update_none']           = 'Обновления не найдены.';
$lang['deleting']              = 'Удаление ...';
$lang['deleted']               = 'Плагин %s удален.';
$lang['downloading']           = 'Скачивание ...';
$lang['downloaded']            = 'Плагин %s успешно установлен';
$lang['downloads']             = 'Следующие плагины были успешно установлены:';
$lang['download_none']         = 'Плагины не найдены, или возникла неизвестная проблема в процессе скачивания и установки.';
$lang['plugin']                = 'Плагин:';
$lang['components']            = 'Компоненты';
$lang['noinfo']                = 'Этот плагин не сообщил никаких данных, он может быть нерабочим.';
$lang['name']                  = 'Название:';
$lang['date']                  = 'Дата:';
$lang['type']                  = 'Тип:';
$lang['desc']                  = 'Описание:';
$lang['author']                = 'Автор:';
$lang['www']                   = 'Страничка:';
$lang['error']                 = 'Произошла неизвестная ошибка.';
$lang['error_download']        = 'Не могу скачать файл плагина: %s';
$lang['error_badurl']          = 'Возможно, неправильный адрес - не могу определить имя файла из адреса';
$lang['error_dircreate']       = 'Не могу создать временную директорию для скачивания';
$lang['error_decompress']      = 'Менеджеру плагинов не удалось распаковать скачанный файл. Это может быть результатом ошибки при скачивании, в этом случае Вы можете попробовать снова; или же плагин упакован неизвестным архиватором, тогда Вам необходимо скачать и установить плагин вручную.';
$lang['error_copy']            = 'Произошла ошибка копирования при попытке установки файлов для плагина <em>%s</em>: переполнение диска или неправильные права доступа. Это могло привести к частичной установке плагина и неустойчивости вашей Вики.';
$lang['error_delete']          = 'Произошла ошибка при попытке удалить плагин <em>%s</em>.  Наиболее вероятно, что нет необходимых прав доступа к файлам или директориям';
$lang['enabled']               = 'Плагин %s включён.';
$lang['notenabled']            = 'Не удалось включить плагин %s. Проверьте системные права доступа к файлам.';
$lang['disabled']              = 'Плагин %s отключён.';
$lang['notdisabled']           = 'Не удалось отключить плагин %s. Проверьте системные права доступа к файлам.';
